@@ -1,4 +1,3 @@
-# pylint: disable=line-too-long
 """Configuration API for laskea."""
 import copy
 import json
@@ -39,7 +38,9 @@ TEMPLATE_EXAMPLE = """\
           "customfield_13901",
           "fields.customfield_13901[].value"
         ]
-      }
+      },
+      "lf_only": true,
+      "join_string": " <br>"
     }
   },
   "remote": {
@@ -67,7 +68,7 @@ def generate_template() -> str:
 def load_configuration(configuration: Dict[str, object]) -> Dict[str, str]:
     """LaterAlligator."""
     if not configuration:
-        print('Warning: Requested load from empty configuration')
+        print('Warning: Requested load from empty configuration', file=sys.stderr)
         return {}
 
     source_of = {}
@@ -90,6 +91,24 @@ def load_configuration(configuration: Dict[str, object]) -> Dict[str, str]:
         source_of['field_map'] = 'env'
         api.BASE_COL_MAPS = json.loads(field_map)
 
+    lf_only = jmespath.search('table.column.lf_only', configuration)
+    if lf_only:
+        source_of['lf_only'] = 'config'
+        api.BASE_LF_ONLY = lf_only
+    lf_only = os.getenv(f'{laskea.APP_ENV}_LF_ONLY', '')
+    if lf_only:
+        source_of['lf_only'] = 'env'
+        api.BASE_LF_ONLY = lf_only
+
+    join_string = jmespath.search('table.column.join_string', configuration)
+    if join_string:
+        source_of['join_string'] = 'config'
+        api.BASE_JOIN_STRING = join_string
+    join_string = os.getenv(f'{laskea.APP_ENV}_JOIN_STRING', '')
+    if join_string:
+        source_of['join_string'] = 'env'
+        api.BASE_JOIN_STRING = join_string
+
     remote_user = jmespath.search('remote.user', configuration)
     if remote_user:
         source_of['remote_user'] = 'config'
@@ -177,10 +196,10 @@ def discover_configuration(conf: str) -> Tuple[Dict[str, object], str]:
     if conf:
         cp = pathlib.Path(conf)
         if not cp.is_file() or not cp.stat().st_size:
-            print('Given configuration path is no file or empty')
+            print('Given configuration path is no file or empty', file=sys.stderr)
             sys.exit(2)
         if not laskea.QUIET:
-            print(f'Reading configuration file {cp} as requested...')
+            print(f'Reading configuration file {cp} as requested...', file=sys.stderr)
         with cp.open() as handle:
             configuration = json.load(handle)
     else:
@@ -190,7 +209,7 @@ def discover_configuration(conf: str) -> Tuple[Dict[str, object], str]:
             cp = pp / cn
             if cp.is_file() and cp.stat().st_size:
                 if not laskea.QUIET:
-                    print(f'Reading from discovered configuration path {cp}')
+                    print(f'Reading from discovered configuration path {cp}', file=sys.stderr)
                 with cp.open() as handle:
                     configuration = json.load(handle)
                 return configuration, str(cp)
@@ -198,13 +217,19 @@ def discover_configuration(conf: str) -> Tuple[Dict[str, object], str]:
         cp = pathlib.Path.home() / laskea.DEFAULT_CONFIG_NAME
         if cp.is_file() and cp.stat().st_size:
             if not laskea.QUIET:
-                print(f'Reading configuration file {cp} from home directory at {pathlib.Path.home()} ...')
+                print(
+                    f'Reading configuration file {cp} from home directory at {pathlib.Path.home()} ...',
+                    file=sys.stderr,
+                )
             with cp.open() as handle:
                 configuration = json.load(handle)
             return configuration, str(cp)
 
         if not laskea.QUIET:
-            print(f'User home configuration path to {cp} is no file or empty - ignoring configuration data')
+            print(
+                f'User home configuration path to {cp} is no file or empty - ignoring configuration data',
+                file=sys.stderr,
+            )
 
     return configuration, str(cp)
 
@@ -223,6 +248,8 @@ def report_context(command: str, transaction_mode: str, vector: List[str]) -> No
     app_env_col_fields = f'{laskea.APP_ENV}_COL_FIELDS'
     app_env_col_maps = f'{laskea.APP_ENV}_COL_MAPS'
     app_env_markers = f'{laskea.APP_ENV}_MARKERS'
+    app_env_lf_only = f'{laskea.APP_ENV}_LF_ONLY'
+    app_env_join_string = f'{laskea.APP_ENV}_JOIN_STRING'
     empty = ''
     print(f'- {laskea.APP_ENV}_USER: ({os.getenv(app_env_user, empty)})', file=sys.stderr)
     print(
@@ -233,6 +260,8 @@ def report_context(command: str, transaction_mode: str, vector: List[str]) -> No
     print(f'- {laskea.APP_ENV}_COL_FIELDS: ({os.getenv(app_env_col_fields, empty)})', file=sys.stderr)
     print(f'- {laskea.APP_ENV}_COL_MAPS: ({os.getenv(app_env_col_maps, empty)})', file=sys.stderr)
     print(f'- {laskea.APP_ENV}_MARKERS: ({os.getenv(app_env_markers, empty)})', file=sys.stderr)
+    print(f'- {laskea.APP_ENV}_LF_ONLY: ({os.getenv(app_env_lf_only, empty)})', file=sys.stderr)
+    print(f'- {laskea.APP_ENV}_JOIN_STRING: ({os.getenv(app_env_join_string, empty)})', file=sys.stderr)
     print('Effective(variable values):', file=sys.stderr)
     print(f'- RemoteUser: ({api.BASE_USER})', file=sys.stderr)
     print(f'- RemoteToken: ({"*" * len(api.BASE_PASS)})', file=sys.stderr)
@@ -240,6 +269,8 @@ def report_context(command: str, transaction_mode: str, vector: List[str]) -> No
     print(f'- ColumnFields(table): ({api.BASE_COL_FIELDS})', file=sys.stderr)
     print(f'- ColumnMaps(remote->table): ({api.BASE_COL_MAPS})', file=sys.stderr)
     print(f'- Markers(pattern): ({laskea.BASE_MARKERS})', file=sys.stderr)
+    print(f'- lf_only: ({laskea.BASE_LF_ONLY})', file=sys.stderr)
+    print(f'- join_string: ({laskea.BASE_JOIN_STRING})', file=sys.stderr)
     print(f'- CallVector: ({vector})', file=sys.stderr)
 
 
@@ -248,10 +279,10 @@ def report_sources_of_effective_configuration(source_of: Dict[str, str], header:
     """DRY."""
     if laskea.QUIET:
         return
-    print(header)
-    print('# --- BEGIN ---')
-    print(json.dumps(source_of, indent=2))
-    print('# --- E N D ---')
+    print(header, file=sys.stderr)
+    print('# --- BEGIN ---', file=sys.stderr)
+    print(json.dumps(source_of, indent=2), file=sys.stderr)
+    print('# --- E N D ---', file=sys.stderr)
 
 
 @no_type_check
@@ -259,13 +290,13 @@ def safe_report_configuration(configuration: Dict[str, object], header: str) ->
     """DRY."""
     if laskea.QUIET:
         return
-    print(header)
-    print('# --- BEGIN ---')
+    print(header, file=sys.stderr)
+    print('# --- BEGIN ---', file=sys.stderr)
     fake_configuration = copy.deepcopy(configuration)
     if jmespath.search('remote.token', fake_configuration):
         fake_configuration['remote']['token'] = laskea.FAKE_SECRET  # noqa
-    print(json.dumps(fake_configuration, indent=2))
-    print('# --- E N D ---')
+    print(json.dumps(fake_configuration, indent=2), file=sys.stderr)
+    print('# --- E N D ---', file=sys.stderr)
 
 
 @no_type_check
@@ -278,16 +309,21 @@ def create_and_report_effective_configuration(header: str) -> None:
             'column': {
                 'fields': copy.deepcopy(api.BASE_COL_FIELDS),
                 'field_map': copy.deepcopy(api.BASE_COL_MAPS),
+                'lf_only': api.BASE_LF_ONLY,
+                'join_string': api.BASE_JOIN_STRING,
             },
         },
         'remote': {
+            'is_cloud': api.BASE_IS_CLOUD,
             'user': api.BASE_USER,
             'token': '',
             'base_url': api.BASE_URL,
         },
         'local': {
             'markers': laskea.BASE_MARKERS,
+            'quiet': laskea.QUIET,
             'verbose': laskea.DEBUG,
+            'strict': laskea.STRICT,
         },
     }
     safe_report_configuration(effective, header)
@@ -308,6 +344,13 @@ def process(conf: str, options: Mapping[str, bool]) -> None:
             report_sources_of_effective_configuration(source_of, f'Configuration source after loading from {cp}:')
 
         if not laskea.QUIET:
-            print('Configuration interface combined file, environment, and commandline values!')
+            print('Configuration interface combined file, environment, and commandline values!', file=sys.stderr)
 
-        create_and_report_effective_configuration(f'Effective configuration combining {cp} and environment variables:')
+        create_and_report_effective_configuration(
+            f'Effective configuration combining {cp}, environment variables, and defaults:'
+        )
+
+    print(
+        f'INFO: Upstream JIRA instance is addressed per {"cloud" if api.BASE_IS_CLOUD else "server"} rules',
+        file=sys.stderr,
+    )
